# coding: utf-8

"""
    ****************************************************************************
    Copyright (c) 2016-present,
    Jaguar0625, gimre, BloodyRookie, Tech Bureau, Corp. All rights reserved.

    This file is part of Catapult.

    Catapult is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Catapult is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Catapult. If not, see <http://www.gnu.org/licenses/>.
    ****************************************************************************
    
    Catapult REST Endpoints
    OpenAPI Specification of catapult-rest 1.1.2  # noqa: E501
    The version of the OpenAPI document: 0.9.3
    Contact: contact@nem.foundation

    NOTE: This file is auto generated by Symbol OpenAPI Generator:
    https://github.com/nemtech/symbol-openapi-generator
    Do not edit this file manually.
"""


from __future__ import absolute_import

import unittest
import datetime

import symbol_openapi_client
from symbol_openapi_client.models.chain_properties_dto import ChainPropertiesDTO  # noqa: E501
from symbol_openapi_client.rest import ApiException

class TestChainPropertiesDTO(unittest.TestCase):
    """ChainPropertiesDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ChainPropertiesDTO
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = symbol_openapi_client.models.chain_properties_dto.ChainPropertiesDTO()  # noqa: E501
        if include_optional :
            return ChainPropertiesDTO(
                enable_verifiable_state = True, 
                enable_verifiable_receipts = True, 
                currency_mosaic_id = '0x24F4'26B8'D549'3D4B', 
                harvesting_mosaic_id = '0x1D9C'DC7E'218C'A88D', 
                block_generation_target_time = '30s', 
                block_time_smoothing_factor = '3000', 
                block_finalization_interval = '30', 
                importance_grouping = '39', 
                importance_activity_percentage = '5', 
                max_rollback_blocks = '40', 
                max_difficulty_blocks = '60', 
                default_dynamic_fee_multiplier = '10000', 
                max_transaction_lifetime = '24h', 
                max_block_future_time = '500ms', 
                initial_currency_atomic_units = '8998999998000000', 
                max_mosaic_atomic_units = '9000000000000000', 
                total_chain_importance = '15000000', 
                min_harvester_balance = '500', 
                max_harvester_balance = '4000000', 
                min_voter_balance = '50000', 
                harvest_beneficiary_percentage = '10', 
                harvest_network_percentage = '5', 
                harvest_network_fee_sink_address = 'SAAA244WMCB2JXGNQTQHQOS45TGBFF4V2MJBVOQ', 
                block_prune_interval = '360', 
                max_transactions_per_block = '200000'
            )
        else :
            return ChainPropertiesDTO(
        )

    def testChainPropertiesDTO(self):
        """Test ChainPropertiesDTO"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ****************************************************************************
    Copyright (c) 2016-present,
    Jaguar0625, gimre, BloodyRookie, Tech Bureau, Corp. All rights reserved.

    This file is part of Catapult.

    Catapult is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Catapult is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Catapult. If not, see <http://www.gnu.org/licenses/>.
    ****************************************************************************
    
    Catapult REST Endpoints
    OpenAPI Specification of catapult-rest 1.1.2  # noqa: E501
    The version of the OpenAPI document: 0.9.3
    Contact: contact@nem.foundation

    NOTE: This file is auto generated by Symbol OpenAPI Generator:
    https://github.com/nemtech/symbol-openapi-generator
    Do not edit this file manually.
"""


import pprint
import re  # noqa: F401

import six

from symbol_openapi_client.configuration import Configuration


class Pagination(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'page_number': 'int',
        'page_size': 'int',
        'total_entries': 'int',
        'total_pages': 'int'
    }

    attribute_map = {
        'page_number': 'pageNumber',
        'page_size': 'pageSize',
        'total_entries': 'totalEntries',
        'total_pages': 'totalPages'
    }

    def __init__(self, page_number=None, page_size=None, total_entries=None, total_pages=None, local_vars_configuration=None):  # noqa: E501
        """Pagination - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._page_number = None
        self._page_size = None
        self._total_entries = None
        self._total_pages = None
        self.discriminator = None

        self.page_number = page_number
        self.page_size = page_size
        self.total_entries = total_entries
        self.total_pages = total_pages

    @property
    def page_number(self):
        """Gets the page_number of this Pagination.  # noqa: E501


        :return: The page_number of this Pagination.  # noqa: E501
        :rtype: int
        """
        return self._page_number

    @page_number.setter
    def page_number(self, page_number):
        """Sets the page_number of this Pagination.


        :param page_number: The page_number of this Pagination.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and page_number is None:  # noqa: E501
            raise ValueError("Invalid value for `page_number`, must not be `None`")  # noqa: E501

        self._page_number = page_number

    @property
    def page_size(self):
        """Gets the page_size of this Pagination.  # noqa: E501


        :return: The page_size of this Pagination.  # noqa: E501
        :rtype: int
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size):
        """Sets the page_size of this Pagination.


        :param page_size: The page_size of this Pagination.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and page_size is None:  # noqa: E501
            raise ValueError("Invalid value for `page_size`, must not be `None`")  # noqa: E501

        self._page_size = page_size

    @property
    def total_entries(self):
        """Gets the total_entries of this Pagination.  # noqa: E501


        :return: The total_entries of this Pagination.  # noqa: E501
        :rtype: int
        """
        return self._total_entries

    @total_entries.setter
    def total_entries(self, total_entries):
        """Sets the total_entries of this Pagination.


        :param total_entries: The total_entries of this Pagination.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and total_entries is None:  # noqa: E501
            raise ValueError("Invalid value for `total_entries`, must not be `None`")  # noqa: E501

        self._total_entries = total_entries

    @property
    def total_pages(self):
        """Gets the total_pages of this Pagination.  # noqa: E501


        :return: The total_pages of this Pagination.  # noqa: E501
        :rtype: int
        """
        return self._total_pages

    @total_pages.setter
    def total_pages(self, total_pages):
        """Sets the total_pages of this Pagination.


        :param total_pages: The total_pages of this Pagination.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and total_pages is None:  # noqa: E501
            raise ValueError("Invalid value for `total_pages`, must not be `None`")  # noqa: E501

        self._total_pages = total_pages

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Pagination):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Pagination):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    ****************************************************************************
    Copyright (c) 2016-present,
    Jaguar0625, gimre, BloodyRookie, Tech Bureau, Corp. All rights reserved.

    This file is part of Catapult.

    Catapult is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Catapult is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Catapult. If not, see <http://www.gnu.org/licenses/>.
    ****************************************************************************
    
    Catapult REST Endpoints
    OpenAPI Specification of catapult-rest 1.1.2  # noqa: E501
    The version of the OpenAPI document: 0.9.3
    Contact: contact@nem.foundation

    NOTE: This file is auto generated by Symbol OpenAPI Generator:
    https://github.com/nemtech/symbol-openapi-generator
    Do not edit this file manually.
"""


from __future__ import absolute_import

import unittest
import datetime

import symbol_openapi_client
from symbol_openapi_client.models.plugins_properties_dto import PluginsPropertiesDTO  # noqa: E501
from symbol_openapi_client.rest import ApiException

class TestPluginsPropertiesDTO(unittest.TestCase):
    """PluginsPropertiesDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PluginsPropertiesDTO
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = symbol_openapi_client.models.plugins_properties_dto.PluginsPropertiesDTO()  # noqa: E501
        if include_optional :
            return PluginsPropertiesDTO(
                accountlink = symbol_openapi_client.models.account_key_link_network_properties_dto.AccountKeyLinkNetworkPropertiesDTO(
                    dummy = '0', ), 
                aggregate = symbol_openapi_client.models.aggregate_network_properties_dto.AggregateNetworkPropertiesDTO(
                    max_transactions_per_aggregate = '1000', 
                    max_cosignatures_per_aggregate = '15', 
                    enable_strict_cosignature_check = False, 
                    enable_bonded_aggregate_support = True, 
                    max_bonded_transaction_lifetime = '48h', ), 
                lockhash = symbol_openapi_client.models.hash_lock_network_properties_dto.HashLockNetworkPropertiesDTO(
                    locked_funds_per_aggregate = '10000000', 
                    max_hash_lock_duration = '2d', ), 
                locksecret = symbol_openapi_client.models.secret_lock_network_properties_dto.SecretLockNetworkPropertiesDTO(
                    max_secret_lock_duration = '30d', 
                    min_proof_size = '1', 
                    max_proof_size = '1000', ), 
                metadata = symbol_openapi_client.models.metadata_network_properties_dto.MetadataNetworkPropertiesDTO(
                    max_value_size = '1024', ), 
                mosaic = symbol_openapi_client.models.mosaic_network_properties_dto.MosaicNetworkPropertiesDTO(
                    max_mosaics_per_account = '10000', 
                    max_mosaic_duration = '3650d', 
                    max_mosaic_divisibility = '6', 
                    mosaic_rental_fee_sink_address = 'SAAA244WMCB2JXGNQTQHQOS45TGBFF4V2MJBVOQ', 
                    mosaic_rental_fee = '500', ), 
                multisig = symbol_openapi_client.models.multisig_network_properties_dto.MultisigNetworkPropertiesDTO(
                    max_multisig_depth = '3', 
                    max_cosignatories_per_account = '10', 
                    max_cosigned_accounts_per_account = '5', ), 
                namespace = symbol_openapi_client.models.namespace_network_properties_dto.NamespaceNetworkPropertiesDTO(
                    max_name_size = '64', 
                    max_child_namespaces = '500', 
                    max_namespace_depth = '3', 
                    min_namespace_duration = '1m', 
                    max_namespace_duration = '365d', 
                    namespace_grace_period_duration = '2m', 
                    reserved_root_namespace_names = 'xem, nem, user, account, org, com, biz, net, edu, mil, gov, info', 
                    namespace_rental_fee_sink_address = 'SAAA244WMCB2JXGNQTQHQOS45TGBFF4V2MJBVOQ', 
                    root_namespace_rental_fee_per_block = '1', 
                    child_namespace_rental_fee = '100', ), 
                restrictionaccount = symbol_openapi_client.models.account_restriction_network_properties_dto.AccountRestrictionNetworkPropertiesDTO(
                    max_account_restriction_values = '512', ), 
                restrictionmosaic = symbol_openapi_client.models.mosaic_restriction_network_properties_dto.MosaicRestrictionNetworkPropertiesDTO(
                    max_mosaic_restriction_values = '20', ), 
                transfer = symbol_openapi_client.models.transfer_network_properties_dto.TransferNetworkPropertiesDTO(
                    max_message_size = '1024', )
            )
        else :
            return PluginsPropertiesDTO(
        )

    def testPluginsPropertiesDTO(self):
        """Test PluginsPropertiesDTO"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
